#
# hello.mag.45.py
#
# receive and display magnetic field 
#    hello.mag.45.py serial_port
#
# Neil Gershenfeld 11/3/13
# (c) Massachusetts Institute of Technology 2013
#
# This work may be reproduced, modified, distributed,
# performed, and displayed for any purpose. Copyright is
# retained and must be preserved. The work is provided
# as is; no warranty is provided, and users accept all 
# liability.

# accelerometer.c
# Modified by Victoria Peredo
#

from Tkinter import *
import serial
import numpy
import math

WINDOW = 800 # window size
nsamples = 100.0 # number of samples accumulated
vref = 3.3
sensi = 0.3
offset_xy = 512
offset_z = 629


def idle(parent,canvas):
  global filter, eps
  #
  # idle routine
  #
  byte2 = 0
  byte3 = 0
  byte4 = 0
  ser.flush()
  while 1:
    #
    # find framing 
    #
    byte1 = byte2
    byte2 = byte3
    byte3 = byte4
    byte4 = ord(ser.read())
    if ((byte1 == 1) & (byte2 == 2) & (byte3 == 3) & (byte4 == 4)):
       break
  
  #Theoretical vlevel = 1.5
  v_level_xy = (offset_xy*vref)/1024;
  v_level_z = (offset_z*vref)/1024;

  #leer 3 trozoz y dividir entre 100  -> mirar media y si no mediana

  x1 = ord(ser.read())   #we read the first 8 bits
  x2 = ord(ser.read())   #we read the second 8 bits
  x_adc = (256*x2 + x1)   #we put them together in the same variable
  x_value = (((x_adc*vref)/1024)-v_level_xy)/sensi;      #Conversion to a voltage level
  
  
  

  #READING THE ACCELERATION OF Y

  y1 = ord(ser.read())
  y2 = ord(ser.read())
  y_adc = (256*y2 + y1)
   
  y_value = (((y_adc*vref)/1024)- v_level_xy)/sensi;

  #For reading the values that are being send from the ACDC we need re-build the two blocks

  #READING THE ACCELERATION OF Z

  z1 = ord(ser.read())
  z2 = ord(ser.read())
  z_adc = (256*z2 + z1)
  z_value = (((z_adc*vref)/1024)- v_level_z)/sensi;

 


  #Displaying the voltage value

  canvas.itemconfigure("accel_z",text="Voltage z %.1f"%z_value)
  canvas.itemconfigure("accel_x",text="Voltage x %.1f"%x_value)     
  canvas.itemconfigure("accel_y",text="Voltage y %.1f"%y_value)



  #Calculating the angle in every axis with the voltage value: extracted from the datasheet

  if x_value==0:
    x_value = 0.001
  if y_value==0:
    y_value = 0.001
  if z_value==0:
    z_value = 0.001

  x_angle = math.atan(x_value / (math.sqrt((y_value**2) + (z_value**2)))) * (180/math.pi);
  
  y_angle = math.atan(y_value / (math.sqrt((x_value**2) + (z_value**2)))) * (180/math.pi);

  z_angle = math.atan((math.sqrt((x_value**2) + (y_value**2)))/z_value) * (180/math.pi);

  canvas.itemconfigure("angle_x",text="Angle x %.1f"%x_angle)
  canvas.itemconfigure("angle_y",text="Angle y %.1f"%y_angle)
  canvas.itemconfigure("angle_z",text="Angle z %.1f"%z_angle)

  #Calculating the total angle 

  total_angle = math.acos(z_value / (math.sqrt((x_value**2) + (y_value**2) + (z_value**2)))) * (180/math.pi); 

  canvas.itemconfigure("angle_total",text="Total angle:  %.1f"%total_angle)

  canvas.update()
  parent.after_idle(idle,parent,canvas)

#
#  check command line arguments
#
if (len(sys.argv) != 2):
   print "command line: accel.py serial_port"
   sys.exit()
port = sys.argv[1]
#
# open serial port
#
ser = serial.Serial(port,9600)
ser.setDTR()
#
# set up GUI
#
root = Tk()
root.title('Accelerometer (q to exit)')
root.bind('q','exit')
canvas = Canvas(root, width=WINDOW, height=.7*WINDOW, background='white')

canvas.create_text(.2*WINDOW,.2*WINDOW,text=".33",font=("Helvetica", 24),tags="accel_x",fill="#0000b0") # x acceleration value
canvas.create_text(.2*WINDOW,.4*WINDOW,text=".33",font=("Helvetica", 24),tags="angle_x",fill="#0000b0") # x angle

canvas.create_text(.5*WINDOW,.2*WINDOW,text=".33",font=("Helvetica", 24),tags="accel_y",fill="#0000b0") # y ADC value
canvas.create_text(.5*WINDOW,.4*WINDOW,text=".33",font=("Helvetica", 24),tags="angle_y",fill="#0000b0") # x angle

canvas.create_text(.8*WINDOW,.2*WINDOW,text=".33",font=("Helvetica", 24),tags="accel_z",fill="#0000b0") # z ADC value
canvas.create_text(.8*WINDOW,.4*WINDOW,text=".33",font=("Helvetica", 24),tags="angle_z",fill="#0000b0") # x angle

canvas.create_text(.5*WINDOW,.6*WINDOW,text=".33",font=("Helvetica", 24),tags="angle_total",fill="#0000b0") # total angle
canvas.pack()
#
# start idle loop
#
root.after(100,idle,root,canvas)
root.mainloop()

